@@ -8,7 +8,4 @@ fn main() {
     );
     let window = window::Window::new(class, "Hello World".to_string(), 1280, 750, 500, 500);
     window.show(WINDOWSTYLE_OVERLAPPED);
-    let msg_box = messagebox::MessageBox::new("Hello!".parse().unwrap(), "world".parse().unwrap());
-    // Normal Dialog
-    msg_box.show(BUTTONSTYLE_NONE, DIALOGSTYLE_NONE, DIALOGHINT_MODAL);
 }
