@@ -1,13 +1,11 @@
-use std::borrow::Borrow;
 use windows_sys::{
     Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect,
     Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*,
 };
-use crate::windowclass::WindowClass;
 
 #[cfg(windows)]
 pub struct Window {
-    pub class: WindowClass,
+    pub class: super::windowclass::WindowClass,
     pub title: String,
     pub width: i32,
     pub height: i32,
@@ -27,11 +25,10 @@ pub struct Window {
 
 #[cfg(windows)]
 impl Window {
-
     ///
     /// Create a new window
     ///
-    pub fn new(class: WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+    pub fn new(class: super::windowclass::WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
         Self {
             class,
             title,
@@ -155,16 +152,14 @@ impl Window {
             }
         }
     }
-
 }
 
 #[cfg(linux)]
 impl Window {
-
     ///
     /// Create a new window
     ///
-    pub fn new(class: WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+    pub fn new(class: super::windowclass::WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
         Self {
             class,
             title,
@@ -235,7 +230,10 @@ impl Window {
 
         window.show_all();
 
-        let application = gtk::Application::new(Some(self.class.clone().get_application_id()), Default::default());
+        let application = gtk::Application::new(
+            Some(self.class.clone().get_application_id()),
+            Default::default(),
+        );
 
         application.run();
     }
