@@ -1,26 +1,26 @@
 use windows_sys::Win32::Foundation::PSTR;
 
 #[cfg(windows)]
-#[derive (Clone, Debug)]
+#[derive(Clone, Debug)]
 pub struct WindowClass {
     class: PSTR,
-    application_id: String
+    application_id: String,
 }
 
 #[cfg(linux)]
-#[derive (Clone, Debug)]
+#[derive(Clone, Debug)]
 pub struct WindowClass {
     class: String,
-    application_id: String
+    application_id: String,
 }
 
 #[cfg(windows)]
 impl WindowClass {
-    pub fn new(classname: String,application_id: String) -> Self {
+    pub fn new(classname: String, application_id: String) -> Self {
         let class: PSTR = classname.as_ptr() as _;
         Self {
             class,
-            application_id
+            application_id,
         }
     }
 
@@ -35,10 +35,10 @@ impl WindowClass {
 
 #[cfg(linux)]
 impl WindowClass {
-    pub fn new(class: String,application_id: String) -> Self {
+    pub fn new(class: String, application_id: String) -> Self {
         Self {
             class,
-            application_id
+            application_id,
         }
     }
 
@@ -49,4 +49,4 @@ impl WindowClass {
     pub fn get_application_id(self) -> String {
         self.application_id
     }
-}
\ No newline at end of file
+}
